@@ -8,7 +8,7 @@ from glob import glob
 modname = "conference"
 distname = "cubicweb-%s" % modname
 
-numversion = (0, 16, 0)
+numversion = (0, 16, 1)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -25,7 +25,7 @@ classifiers = [
 ]
 
 __depends__ = {
-    "cubicweb": ">= 3.29,<3.30",
+    "cubicweb": ">= 3.29",
     "cubicweb-addressbook": None,
     "cubicweb-card": ">=1.1.0",
     "cubicweb-comment": None,
